@@ -127,6 +127,12 @@ class ScanCommand:
                         self.results['wavelength'].append(cavity.get_wavelength())
                         self.results['detector_voltage'].append(detectorVoltage)
 
+                        self.activeCavity = activeCavity
+                        self.currentX = currentX
+                        self.currentY = currentY
+                        self.detectorVoltage = detectorVoltage
+
+
             else:
                 if not self.stopped.wait(2.0):
                     self.results = {'active_cavity': [1, 1, 2, 2, 3, 3, 4, 4],
