@@ -154,7 +154,7 @@ class VCMirrorController(StageController):
                 self._device = None
 
     def _connect(self):
-        self._device = VCMirror(self._port)
+        self._device = VCMirror(self._port, loop_delay=0.05)
         self._device.open()
         self._device_info = {'serial_number': self._device.serial_number, 'model': 'MR-E-2',
                              'firmware_version': self._device.sw_verison}
